@@ -89,7 +89,7 @@ COMMENT ON FUNCTION ST_SquareGrid(float8, geometry) IS 'args: size, bounds - Ret
 			
 COMMENT ON FUNCTION ST_Square(float8, integer, integer, geometry) IS 'args: size, cell_i, cell_j, origin - Returns a single square, using the provided edge size and cell coordinate within the square grid space.';
 			
-COMMENT ON FUNCTION ST_Letters(text, json) IS 'args:  letters,  font - Returns the input letters rendered as geometry with a default start position at the origin and default text height of 100.';
+COMMENT ON FUNCTION ST_Letters(text, json) IS 'args: letters, font - Returns the input letters rendered as geometry with a default start position at the origin and default text height of 100.';
 			
 COMMENT ON FUNCTION GeometryType(geometry ) IS 'args: geomA - Returns the type of a geometry as text.';
 			
@@ -123,6 +123,10 @@ COMMENT ON FUNCTION ST_HasArc(geometry ) IS 'args: geomA - Tests if a geometry c
 			
 COMMENT ON FUNCTION ST_InteriorRingN(geometry , integer ) IS 'args: a_polygon, n - Returns the Nth interior ring (hole) of a Polygon.';
 			
+COMMENT ON FUNCTION ST_NumCurves(geometry ) IS 'args: a_compoundcurve - Return the number of component curves in a CompoundCurve.';
+			
+COMMENT ON FUNCTION ST_CurveN(geometry , integer ) IS 'args: a_compoundcurve, index - Returns the Nth component curve geometry of a CompoundCurve.';
+			
 COMMENT ON FUNCTION ST_IsClosed(geometry ) IS 'args: g - Tests if a LineStringss start and end points are coincident. For a PolyhedralSurface tests if it is closed (volumetric).';
 			
 COMMENT ON FUNCTION ST_IsCollection(geometry ) IS 'args: g - Tests if a geometry is a geometry collection type.';
@@ -177,6 +181,10 @@ COMMENT ON FUNCTION ST_Z(geometry ) IS 'args: a_point - Returns the Z coordinate
 			
 COMMENT ON FUNCTION ST_Zmflag(geometry ) IS 'args: geomA - Returns a code indicating the ZM coordinate dimension of a geometry.';
 			
+COMMENT ON FUNCTION ST_HasZ(geometry) IS 'args: geom - Checks if a geometry has a Z dimension.';
+			
+COMMENT ON FUNCTION ST_HasM(geometry) IS 'args: geom - Checks if a geometry has an M (measure) dimension.';
+			
 COMMENT ON FUNCTION ST_AddPoint(geometry, geometry) IS 'args: linestring, point - Add a point to a LineString.';
 			
 COMMENT ON FUNCTION ST_AddPoint(geometry, geometry, integer) IS 'args: linestring, point, position = -1 - Add a point to a LineString.';
@@ -203,10 +211,12 @@ COMMENT ON FUNCTION ST_Force3DM(geometry , float ) IS 'args: geomA, Mvalue = 0.0
 			
 COMMENT ON FUNCTION ST_Force4D(geometry , float , float ) IS 'args: geomA, Zvalue = 0.0, Mvalue = 0.0 - Force the geometries into XYZM mode.';
 			
-COMMENT ON FUNCTION ST_ForcePolygonCCW(geometry) IS 'args: geom - Orients all exterior rings counter-clockwise and all interior rings clockwise.';
-			
 COMMENT ON FUNCTION ST_ForceCollection(geometry ) IS 'args: geomA - Convert the geometry into a GEOMETRYCOLLECTION.';
 			
+COMMENT ON FUNCTION ST_ForceCurve(geometry) IS 'args: g - Upcast a geometry into its curved type, if applicable.';
+			
+COMMENT ON FUNCTION ST_ForcePolygonCCW(geometry) IS 'args: geom - Orients all exterior rings counter-clockwise and all interior rings clockwise.';
+			
 COMMENT ON FUNCTION ST_ForcePolygonCW(geometry) IS 'args: geom - Orients all exterior rings clockwise and all interior rings counter-clockwise.';
 			
 COMMENT ON FUNCTION ST_ForceSFS(geometry ) IS 'args: geomA - Force the geometries to use SFS 1.1 geometry types only.';
@@ -215,7 +225,7 @@ COMMENT ON FUNCTION ST_ForceSFS(geometry , text ) IS 'args: geomA, version - For
 			
 COMMENT ON FUNCTION ST_ForceRHR(geometry) IS 'args: g - Force the orientation of the vertices in a polygon to follow the Right-Hand-Rule.';
 			
-COMMENT ON FUNCTION ST_ForceCurve(geometry) IS 'args: g - Upcast a geometry into its curved type, if applicable.';
+COMMENT ON FUNCTION ST_LineExtend(geometry , float , float) IS 'args: line, distance_forward, distance_backward=0.0 - Returns a line extended forwards and backwards by specified distances.';
 			
 COMMENT ON FUNCTION ST_LineToCurve(geometry ) IS 'args: geomANoncircular - Converts a linear geometry to a curved geometry.';
 			
@@ -223,17 +233,29 @@ COMMENT ON FUNCTION ST_Multi(geometry ) IS 'args: geom - Return the geometry as
 			
 COMMENT ON FUNCTION ST_Normalize(geometry ) IS 'args: geom - Return the geometry in its canonical form.';
 			
+COMMENT ON FUNCTION ST_Project(geometry , float , float ) IS 'args: g1, distance, azimuth - Returns a point projected from a start point by a distance and bearing (azimuth).';
+			
+COMMENT ON FUNCTION ST_Project(geometry , geometry , float ) IS 'args: g1, g2, distance - Returns a point projected from a start point by a distance and bearing (azimuth).';
+			
+COMMENT ON FUNCTION ST_Project(geography , float , float ) IS 'args: g1, distance, azimuth - Returns a point projected from a start point by a distance and bearing (azimuth).';
+			
+COMMENT ON FUNCTION ST_Project(geography , geography , float ) IS 'args: g1, g2, distance - Returns a point projected from a start point by a distance and bearing (azimuth).';
+			
 COMMENT ON FUNCTION ST_QuantizeCoordinates(geometry, int, int, int, int) IS 'args: g, prec_x, prec_y, prec_z, prec_m - Sets least significant bits of coordinates to zero';
 			
 COMMENT ON FUNCTION ST_RemovePoint(geometry, integer) IS 'args: linestring, offset - Remove a point from a linestring.';
 			
 COMMENT ON FUNCTION ST_RemoveRepeatedPoints(geometry, float8) IS 'args: geom, tolerance - Returns a version of a geometry with duplicate points removed.';
 			
+COMMENT ON FUNCTION ST_RemoveIrrelevantPointsForView(geometry , box2d , boolean ) IS 'args: geom, bounds, cartesian_hint = false - Removes points that are irrelevant for rendering a specific rectangluar view of a geometry.';
+			
+COMMENT ON FUNCTION ST_RemoveSmallParts(geometry , double precision , double precision ) IS 'args: geom, minSizeX, minSizeY - Removes small parts (polygon rings or linestrings) of a geometry.';
+			
 COMMENT ON FUNCTION ST_Reverse(geometry ) IS 'args: g1 - Return the geometry with vertex order reversed.';
 			
-COMMENT ON FUNCTION ST_Segmentize(geometry , float ) IS 'args: geom, max_segment_length - Return a modified geometry/geography having no segment longer than the given distance.';
+COMMENT ON FUNCTION ST_Segmentize(geometry , float ) IS 'args: geom, max_segment_length - Returns a modified geometry/geography having no segment longer than a given distance.';
 			
-COMMENT ON FUNCTION ST_Segmentize(geography , float ) IS 'args: geog, max_segment_length - Return a modified geometry/geography having no segment longer than the given distance.';
+COMMENT ON FUNCTION ST_Segmentize(geography , float ) IS 'args: geog, max_segment_length - Returns a modified geometry/geography having no segment longer than a given distance.';
 			
 COMMENT ON FUNCTION ST_SetPoint(geometry, integer, geometry) IS 'args: linestring, zerobasedposition, point - Replace point of a linestring with a given point.';
 			
@@ -267,6 +289,8 @@ COMMENT ON FUNCTION ST_MakeValid(geometry) IS 'args: input - Attempts to make an
 			
 COMMENT ON FUNCTION ST_MakeValid(geometry, text) IS 'args: input, params - Attempts to make an invalid geometry valid without losing vertices.';
 			
+COMMENT ON FUNCTION ST_InverseTransformPipeline(geometry , text , integer ) IS 'args: geom, pipeline, to_srid - Return a new geometry with coordinates transformed to a different spatial reference system using the inverse of a defined coordinate transformation pipeline.';
+			
 COMMENT ON FUNCTION ST_SetSRID(geometry , integer ) IS 'args: geom, srid - Set the SRID on a geometry.';
 			
 COMMENT ON FUNCTION ST_SRID(geometry ) IS 'args: g1 - Returns the spatial reference identifier for a geometry.';
@@ -279,9 +303,19 @@ COMMENT ON FUNCTION ST_Transform(geometry , text , text ) IS 'args: geom, from_p
 			
 COMMENT ON FUNCTION ST_Transform(geometry , text , integer ) IS 'args: geom, from_proj, to_srid - Return a new geometry with coordinates transformed to a different spatial reference system.';
 			
+COMMENT ON FUNCTION ST_TransformPipeline(geometry , text , integer ) IS 'args: g1, pipeline, to_srid - Return a new geometry with coordinates transformed to a different spatial reference system using a defined coordinate transformation pipeline.';
+			
+COMMENT ON FUNCTION postgis_srs_codes(text ) IS 'args: auth_name - Return the list of SRS codes associated with the given authority.';
+			
+COMMENT ON FUNCTION postgis_srs(text , text ) IS 'args: auth_name, auth_srid - Return a metadata record for the requested authority and srid.';
+			
+COMMENT ON FUNCTION postgis_srs_all() IS 'Return metadata records for every spatial reference system in the underlying Proj database.';
+			
+COMMENT ON FUNCTION postgis_srs_search(geometry , text ) IS 'args: bounds, auth_name=EPSG - Return metadata records for projected coordinate systems that have areas of usage that fully contain the bounds parameter.';
+			
 COMMENT ON FUNCTION ST_Area(geometry ) IS 'args: g1 - Returns the area of a polygonal geometry.';
 			
-COMMENT ON FUNCTION ST_Area(geography , boolean ) IS 'args: geog, use_spheroid=true - Returns the area of a polygonal geometry.';
+COMMENT ON FUNCTION ST_Area(geography , boolean ) IS 'args: geog, use_spheroid = true - Returns the area of a polygonal geometry.';
 			
 COMMENT ON FUNCTION ST_Azimuth(geometry , geometry ) IS 'args: origin, target - Returns the north-based azimuth of a line between two points.';
 			
@@ -293,11 +327,13 @@ COMMENT ON FUNCTION ST_Angle(geometry , geometry ) IS 'args: line1, line2 - Retu
 			
 COMMENT ON FUNCTION ST_ClosestPoint(geometry , geometry ) IS 'args: geom1, geom2 - Returns the 2D point on g1 that is closest to g2. This is the first point of the shortest line from one geometry to the other.';
 			
+COMMENT ON FUNCTION ST_ClosestPoint(geography , geography , boolean ) IS 'args: geom1, geom2, use_spheroid = true - Returns the 2D point on g1 that is closest to g2. This is the first point of the shortest line from one geometry to the other.';
+			
 COMMENT ON FUNCTION ST_3DClosestPoint(geometry , geometry ) IS 'args: g1, g2 - Returns the 3D point on g1 that is closest to g2. This is the first point of the 3D shortest line.';
 			
 COMMENT ON FUNCTION ST_Distance(geometry , geometry ) IS 'args: g1, g2 - Returns the distance between two geometry or geography values.';
 			
-COMMENT ON FUNCTION ST_Distance(geography , geography , boolean ) IS 'args: geog1, geog2, use_spheroid=true - Returns the distance between two geometry or geography values.';
+COMMENT ON FUNCTION ST_Distance(geography , geography , boolean ) IS 'args: geog1, geog2, use_spheroid = true - Returns the distance between two geometry or geography values.';
 			
 COMMENT ON FUNCTION ST_3DDistance(geometry , geometry ) IS 'args: g1, g2 - Returns the 3D cartesian minimum distance (based on spatial ref) between two geometries in projected units.';
 			
@@ -313,7 +349,7 @@ COMMENT ON FUNCTION ST_HausdorffDistance(geometry , geometry , float) IS 'args:
 			
 COMMENT ON FUNCTION ST_Length(geometry ) IS 'args: a_2dlinestring - Returns the 2D length of a linear geometry.';
 			
-COMMENT ON FUNCTION ST_Length(geography , boolean ) IS 'args: geog, use_spheroid=true - Returns the 2D length of a linear geometry.';
+COMMENT ON FUNCTION ST_Length(geography , boolean ) IS 'args: geog, use_spheroid = true - Returns the 2D length of a linear geometry.';
 			
 COMMENT ON FUNCTION ST_Length2D(geometry ) IS 'args: a_2dlinestring - Returns the 2D length of a linear geometry. Alias for ST_Length';
 			
@@ -335,16 +371,16 @@ COMMENT ON FUNCTION ST_MinimumClearanceLine(geometry ) IS 'args: g - Returns the
 			
 COMMENT ON FUNCTION ST_Perimeter(geometry ) IS 'args: g1 - Returns the length of the boundary of a polygonal geometry or geography.';
 			
-COMMENT ON FUNCTION ST_Perimeter(geography , boolean ) IS 'args: geog, use_spheroid=true - Returns the length of the boundary of a polygonal geometry or geography.';
+COMMENT ON FUNCTION ST_Perimeter(geography , boolean ) IS 'args: geog, use_spheroid = true - Returns the length of the boundary of a polygonal geometry or geography.';
 			
 COMMENT ON FUNCTION ST_Perimeter2D(geometry ) IS 'args: geomA - Returns the 2D perimeter of a polygonal geometry. Alias for ST_Perimeter.';
 			
 COMMENT ON FUNCTION ST_3DPerimeter(geometry ) IS 'args: geomA - Returns the 3D perimeter of a polygonal geometry.';
 			
-COMMENT ON FUNCTION ST_Project(geography , float , float ) IS 'args: g1, distance, azimuth - Returns a point projected from a start point by a distance and bearing (azimuth).';
-			
 COMMENT ON FUNCTION ST_ShortestLine(geometry , geometry ) IS 'args: geom1, geom2 - Returns the 2D shortest line between two geometries';
 			
+COMMENT ON FUNCTION ST_ShortestLine(geography , geography , boolean ) IS 'args: geom1, geom2, use_spheroid = true - Returns the 2D shortest line between two geometries';
+			
 COMMENT ON FUNCTION ST_3DShortestLine(geometry , geometry ) IS 'args: g1, g2 - Returns the 3D shortest line between two geometries';
 			
 COMMENT ON FUNCTION ST_ClipByBox2D(geometry, box2d) IS 'args: geom, box - Computes the portion of a geometry falling within a rectangle.';
@@ -389,21 +425,19 @@ COMMENT ON FUNCTION ST_BuildArea(geometry ) IS 'args: geom - Creates a polygonal
 			
 COMMENT ON FUNCTION ST_Centroid(geometry ) IS 'args: g1 - Returns the geometric center of a geometry.';
 			
-COMMENT ON FUNCTION ST_Centroid(geography , boolean ) IS 'args: g1, use_spheroid=true - Returns the geometric center of a geometry.';
+COMMENT ON FUNCTION ST_Centroid(geography , boolean ) IS 'args: g1, use_spheroid = true - Returns the geometric center of a geometry.';
 			
 COMMENT ON FUNCTION ST_ChaikinSmoothing(geometry, integer, boolean) IS 'args: geom, nIterations = 1, preserveEndPoints = false - Returns a smoothed version of a geometry, using the Chaikin algorithm';
 			
-COMMENT ON FUNCTION ST_ConcaveHull(geometry , float , boolean ) IS 'args: param_geom, param_pctconvex, param_allow_holes = false - Computes a possibly concave geometry that encloses all input geometry vertices';
+COMMENT ON FUNCTION ST_ConcaveHull(geometry , float , boolean ) IS 'args: param_geom, param_pctconvex, param_allow_holes = false - Computes a possibly concave geometry that contains all input geometry vertices';
 			
 COMMENT ON FUNCTION ST_ConvexHull(geometry ) IS 'args: geomA - Computes the convex hull of a geometry.';
 			
-COMMENT ON FUNCTION ST_DelaunayTriangles(geometry , float , int4 ) IS 'args: g1, tolerance, flags - Returns the Delaunay triangulation of the vertices of a geometry.';
+COMMENT ON FUNCTION ST_DelaunayTriangles(geometry , float , int4 ) IS 'args: g1, tolerance = 0.0, flags = 0 - Returns the Delaunay triangulation of the vertices of a geometry.';
 			
 COMMENT ON FUNCTION ST_FilterByM(geometry, double precision, double precision, boolean) IS 'args: geom, min, max = null, returnM = false - Removes vertices based on their M value';
 			
-COMMENT ON FUNCTION ST_GeneratePoints(geometry, integer) IS 'args: g, npoints - Generates random points contained in a Polygon or MultiPolygon.';
-			
-COMMENT ON FUNCTION ST_GeneratePoints(geometry, integer, integer) IS 'args: g, npoints, seed - Generates random points contained in a Polygon or MultiPolygon.';
+COMMENT ON FUNCTION ST_GeneratePoints(geometry, integer, integer) IS 'args: g, npoints, seed = 0 - Generates a multipoint of random points contained in a Polygon or MultiPolygon.';
 			
 COMMENT ON FUNCTION ST_GeometricMedian(geometry, float8, int, boolean) IS 'args: geom, tolerance = NULL, max_iter = 10000, fail_if_not_converged = false - Returns the geometric median of a MultiPoint.';
 			
@@ -413,6 +447,8 @@ COMMENT ON FUNCTION ST_LineMerge(geometry , boolean ) IS 'args: amultilinestring
 			
 COMMENT ON FUNCTION ST_MaximumInscribedCircle(geometry ) IS 'args: geom - Computes the largest circle contained within a geometry.';
 			
+COMMENT ON FUNCTION ST_LargestEmptyCircle(geometry , double precision , geometry ) IS 'args: geom, tolerance=0.0, boundary=POINT EMPTY - Computes the largest circle not overlapping a geometry.';
+			
 COMMENT ON FUNCTION ST_MinimumBoundingCircle(geometry , integer ) IS 'args: geomA, num_segs_per_qt_circ=48 - Returns the smallest circle polygon that contains a geometry.';
 			
 COMMENT ON FUNCTION ST_MinimumBoundingRadius(geometry) IS 'args: geom - Returns the center point and radius of the smallest circle that contains a geometry.';
@@ -431,23 +467,29 @@ COMMENT ON FUNCTION ST_ReducePrecision(geometry , float8 ) IS 'args: g, gridsize
 			
 COMMENT ON FUNCTION ST_SharedPaths(geometry, geometry) IS 'args: lineal1, lineal2 - Returns a collection containing paths shared by the two input linestrings/multilinestrings.';
 			
-COMMENT ON FUNCTION ST_Simplify(geometry, float) IS 'args: geomA, tolerance - Returns a simplified version of a geometry, using the Douglas-Peucker algorithm.';
+COMMENT ON FUNCTION ST_Simplify(geometry, float) IS 'args: geom, tolerance - Returns a simplified representation of a geometry, using the Douglas-Peucker algorithm.';
 			
-COMMENT ON FUNCTION ST_Simplify(geometry, float, boolean) IS 'args: geomA, tolerance, preserveCollapsed - Returns a simplified version of a geometry, using the Douglas-Peucker algorithm.';
+COMMENT ON FUNCTION ST_Simplify(geometry, float, boolean) IS 'args: geom, tolerance, preserveCollapsed - Returns a simplified representation of a geometry, using the Douglas-Peucker algorithm.';
 			
-COMMENT ON FUNCTION ST_SimplifyPreserveTopology(geometry, float) IS 'args: geomA, tolerance - Returns a simplified and valid version of a geometry, using the Douglas-Peucker algorithm.';
+COMMENT ON FUNCTION ST_SimplifyPreserveTopology(geometry, float) IS 'args: geom, tolerance - Returns a simplified and valid representation of a geometry, using the Douglas-Peucker algorithm.';
 			
 COMMENT ON FUNCTION ST_SimplifyPolygonHull(geometry , float , boolean ) IS 'args: param_geom, vertex_fraction, is_outer = true - Computes a simplifed topology-preserving outer or inner hull of a polygonal geometry.';
 			
-COMMENT ON FUNCTION ST_SimplifyVW(geometry, float) IS 'args: geomA, tolerance - Returns a simplified version of a geometry, using the Visvalingam-Whyatt algorithm';
+COMMENT ON FUNCTION ST_SimplifyVW(geometry, float) IS 'args: geom, tolerance - Returns a simplified representation of a geometry, using the Visvalingam-Whyatt algorithm';
 			
-COMMENT ON FUNCTION ST_SetEffectiveArea(geometry, float, integer) IS 'args: geomA, threshold = 0, set_area = 1 - Sets the effective area for each vertex, using the Visvalingam-Whyatt algorithm.';
+COMMENT ON FUNCTION ST_SetEffectiveArea(geometry, float, integer) IS 'args: geom, threshold = 0, set_area = 1 - Sets the effective area for each vertex, using the Visvalingam-Whyatt algorithm.';
 			
 COMMENT ON FUNCTION ST_TriangulatePolygon(geometry) IS 'args: geom - Computes the constrained Delaunay triangulation of polygons';
 			
-COMMENT ON FUNCTION ST_VoronoiLines(geometry, float8, geometry) IS 'args: g1, tolerance, extend_to - Returns the boundaries of the Voronoi diagram of the vertices of a geometry.';
+COMMENT ON FUNCTION ST_VoronoiLines(geometry, float8, geometry) IS 'args: geom, tolerance = 0.0, extend_to = NULL - Returns the boundaries of the Voronoi diagram of the vertices of a geometry.';
 			
-COMMENT ON FUNCTION ST_VoronoiPolygons(geometry, float8, geometry) IS 'args: g1, tolerance, extend_to - Returns the cells of the Voronoi diagram of the vertices of a geometry.';
+COMMENT ON FUNCTION ST_VoronoiPolygons(geometry, float8, geometry) IS 'args: geom, tolerance = 0.0, extend_to = NULL - Returns the cells of the Voronoi diagram of the vertices of a geometry.';
+			
+COMMENT ON FUNCTION ST_CoverageInvalidEdges(geometry, float8 ) IS 'args: geom, tolerance = 0 - Window function that finds locations where polygons fail to form a valid coverage.';
+			
+COMMENT ON FUNCTION ST_CoverageSimplify(geometry, float8 , boolean ) IS 'args: geom, tolerance, simplifyBoundary = true - Window function that simplifies the edges of a polygonal coverage.';
+			
+COMMENT ON AGGREGATE ST_CoverageUnion(geometry) IS 'args: geom - Computes the union of a set of polygons forming a coverage by removing shared edges.';
 			
 COMMENT ON FUNCTION ST_Affine(geometry , float , float , float , float , float , float , float , float , float , float , float , float ) IS 'args: geomA, a, b, c, d, e, f, g, h, i, xoff, yoff, zoff - Apply a 3D affine transformation to a geometry.';
 			
@@ -481,11 +523,15 @@ COMMENT ON FUNCTION ST_TransScale(geometry , float, float, float, float) IS 'arg
 			
 COMMENT ON FUNCTION ST_ClusterDBSCAN(geometry, float8 , integer ) IS 'args: geom, eps, minpoints - Window function that returns a cluster id for each input geometry using the DBSCAN algorithm.';
 			
-COMMENT ON AGGREGATE ST_ClusterIntersecting(geometry) IS 'args: g - Aggregate function that clusters the input geometries into connected sets.';
+COMMENT ON AGGREGATE ST_ClusterIntersecting(geometry) IS 'args: g - Aggregate function that clusters input geometries into connected sets.';
+			
+COMMENT ON FUNCTION ST_ClusterIntersectingWin(geometry) IS 'args: geom - Window function that returns a cluster id for each input geometry, clustering input geometries into connected sets.';
 			
 COMMENT ON FUNCTION ST_ClusterKMeans(geometry, integer , float ) IS 'args: geom, number_of_clusters, max_radius - Window function that returns a cluster id for each input geometry using the K-means algorithm.';
 			
-COMMENT ON AGGREGATE ST_ClusterWithin(geometry, float8 ) IS 'args: g, distance - Aggregate function that clusters the input geometries by separation distance.';
+COMMENT ON AGGREGATE ST_ClusterWithin(geometry, float8 ) IS 'args: g, distance - Aggregate function that clusters geometries by separation distance.';
+			
+COMMENT ON FUNCTION ST_ClusterWithinWin(geometry, float8 ) IS 'args: geom, distance - Window function that returns a cluster id for each input geometry, clustering using separation distance.';
 			
 COMMENT ON FUNCTION Box2D(geometry ) IS 'args: geom - Returns a BOX2D representing the 2D extent of a geometry.';
 			
@@ -531,14 +577,22 @@ COMMENT ON FUNCTION ST_ZMin(box3d ) IS 'args: aGeomorBox2DorBox3D - Returns the
 			
 COMMENT ON FUNCTION ST_LineInterpolatePoint(geometry , float8 ) IS 'args: a_linestring, a_fraction - Returns a point interpolated along a line at a fractional location.';
 			
+COMMENT ON FUNCTION ST_LineInterpolatePoint(geography , float8 , boolean ) IS 'args: a_linestring, a_fraction, use_spheroid = true - Returns a point interpolated along a line at a fractional location.';
+			
 COMMENT ON FUNCTION ST_3DLineInterpolatePoint(geometry , float8 ) IS 'args: a_linestring, a_fraction - Returns a point interpolated along a 3D line at a fractional location.';
 			
 COMMENT ON FUNCTION ST_LineInterpolatePoints(geometry , float8 , boolean ) IS 'args: a_linestring, a_fraction, repeat - Returns points interpolated along a line at a fractional interval.';
 			
+COMMENT ON FUNCTION ST_LineInterpolatePoints(geography , float8 , boolean , boolean ) IS 'args: a_linestring, a_fraction, use_spheroid = true, repeat = true - Returns points interpolated along a line at a fractional interval.';
+			
 COMMENT ON FUNCTION ST_LineLocatePoint(geometry , geometry ) IS 'args: a_linestring, a_point - Returns the fractional location of the closest point on a line to a point.';
 			
+COMMENT ON FUNCTION ST_LineLocatePoint(geography , geography , boolean ) IS 'args: a_linestring, a_point, use_spheroid = true - Returns the fractional location of the closest point on a line to a point.';
+			
 COMMENT ON FUNCTION ST_LineSubstring(geometry , float8 , float8 ) IS 'args: a_linestring, startfraction, endfraction - Returns the part of a line between two fractional locations.';
 			
+COMMENT ON FUNCTION ST_LineSubstring(geography , float8 , float8 ) IS 'args: a_linestring, startfraction, endfraction - Returns the part of a line between two fractional locations.';
+			
 COMMENT ON FUNCTION ST_LocateAlong(geometry , float8 , float8 ) IS 'args: geom_with_measure, measure, offset = 0 - Returns the point(s) on a geometry that match a measure value.';
 			
 COMMENT ON FUNCTION ST_LocateBetween(geometry , float8 , float8 , float8 ) IS 'args: geom, measure_start, measure_end, offset = 0 - Returns the portions of a geometry that match a measure range.';
@@ -557,40 +611,28 @@ COMMENT ON FUNCTION ST_DistanceCPA(geometry , geometry ) IS 'args: track1, track
 			
 COMMENT ON FUNCTION ST_CPAWithin(geometry , geometry , float8 ) IS 'args: track1, track2, dist - Tests if the closest point of approach of two trajectoriesis within the specified distance.';
 			
-COMMENT ON FUNCTION AddAuth(text ) IS 'args: auth_token - Adds an authorization token to be used in the current transaction.';
-			
-COMMENT ON FUNCTION CheckAuth(text , text , text ) IS 'args: a_schema_name, a_table_name, a_key_column_name - Creates a trigger on a table to prevent/allow updates and deletes of rows based on authorization token.';
-			
-COMMENT ON FUNCTION CheckAuth(text , text ) IS 'args: a_table_name, a_key_column_name - Creates a trigger on a table to prevent/allow updates and deletes of rows based on authorization token.';
-			
-COMMENT ON FUNCTION DisableLongTransactions() IS 'Disables long transaction support.';
-			
-COMMENT ON FUNCTION EnableLongTransactions() IS 'Enables long transaction support.';
-			
-COMMENT ON FUNCTION LockRow(text , text , text , text, timestamp) IS 'args: a_schema_name, a_table_name, a_row_key, an_auth_token, expire_dt - Sets lock/authorization for a row in a table.';
-			
-COMMENT ON FUNCTION LockRow(text , text , text, timestamp) IS 'args: a_table_name, a_row_key, an_auth_token, expire_dt - Sets lock/authorization for a row in a table.';
-			
-COMMENT ON FUNCTION LockRow(text , text , text) IS 'args: a_table_name, a_row_key, an_auth_token - Sets lock/authorization for a row in a table.';
-			
-COMMENT ON FUNCTION UnlockRows(text ) IS 'args: auth_token - Removes all locks held by an authorization token.';
-			
-COMMENT ON FUNCTION PostGIS_Extensions_Upgrade() IS 'Packages and upgrades PostGIS extensions (e.g. postgis_raster,postgis_topology, postgis_sfcgal) to latest available version.';
+COMMENT ON FUNCTION PostGIS_Extensions_Upgrade(text) IS 'args: target_version=null - Packages and upgrades PostGIS extensions (e.g. postgis_raster,postgis_topology, postgis_sfcgal) to given or latest version.';
 			
 COMMENT ON FUNCTION PostGIS_Full_Version() IS 'Reports full PostGIS version and build configuration infos.';
 			
 COMMENT ON FUNCTION PostGIS_GEOS_Version() IS 'Returns the version number of the GEOS library.';
 			
+COMMENT ON FUNCTION PostGIS_GEOS_Compiled_Version() IS 'Returns the version number of the GEOS library against which PostGIS was built.';
+			
 COMMENT ON FUNCTION PostGIS_Liblwgeom_Version() IS 'Returns the version number of the liblwgeom library. This should match the version of PostGIS.';
 			
 COMMENT ON FUNCTION PostGIS_LibXML_Version() IS 'Returns the version number of the libxml2 library.';
 			
+COMMENT ON FUNCTION PostGIS_LibJSON_Version() IS 'Returns the version number of the libjson-c library.';
+			
 COMMENT ON FUNCTION PostGIS_Lib_Build_Date() IS 'Returns build date of the PostGIS library.';
 			
 COMMENT ON FUNCTION PostGIS_Lib_Version() IS 'Returns the version number of the PostGIS library.';
 			
 COMMENT ON FUNCTION PostGIS_PROJ_Version() IS 'Returns the version number of the PROJ4 library.';
 			
+COMMENT ON FUNCTION PostGIS_PROJ_Compiled_Version() IS 'Returns the version number of the PROJ library against which PostGIS was built.';
+			
 COMMENT ON FUNCTION PostGIS_Wagyu_Version() IS 'Returns the version number of the internal Wagyu library.';
 			
 COMMENT ON FUNCTION PostGIS_Scripts_Build_Date() IS 'Returns build date of the PostGIS scripts.';
